==> ejc-outcontract-impl-3.0.0-20251024.024608-373-sources.jar: com/ejianc/foundation/outcontract/service/impl/OutcontractBpmServiceImpl.java <==
package com.ejianc.foundation.outcontract.service.impl;

import java.util.Date;

import com.ejianc.foundation.sealApproval.service.IZjkjTianJianSyncService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.foundation.outcontract.bean.OutcontractEntity;
import com.ejianc.foundation.outcontract.bean.OutcontractReviewEntity;
import com.ejianc.foundation.outcontract.service.IOutcontractReviewService;
import com.ejianc.foundation.outcontract.service.IOutcontractService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("outcontract") 
public class OutcontractBpmServiceImpl implements ICommonBusinessService {
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOutcontractService outcontractService;
	@Autowired
	private IZjkjTianJianSyncService zjkjTianJianSyncService;
    
//    @Autowired
//    private IOutcontractReviewService outcontractReviewService;

    @Autowired
    private IBillTypeApi billTypeApi;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		/*OutcontractEntity entity = outcontractService.selectById(billId);
		if("劳务分包".equals(entity.getType())||"专业分包".equals(entity.getType())){
			//没有合同评审不能提交
			OutcontractReviewEntity reviewEntity = outcontractReviewService.selectById(billId);
			if(reviewEntity!=null){
				return CommonResponse.success();
			}else{
				return CommonResponse.error("缺少合同评审信息，不能提交单据！");
			}
		}*/
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(new Date());
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(null);
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/*if(state==0){
			//没有合同评审不能提交
			OutcontractEntity entity = outcontractService.selectById(billId);
			if("劳务分包".equals(entity.getType())||"专业分包".equals(entity.getType())){
				//没有合同评审不能提交
				OutcontractReviewEntity reviewEntity = outcontractReviewService.selectById(billId);
				if(reviewEntity!=null){
					return CommonResponse.success();
				}else{
					return CommonResponse.error("缺少合同评审信息，不能提交单据！");
				}
			}
		}*/
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSignDate(new Date());
		if(state == 1){
			entity.setSubmitDate(new Date());
		}
		entity.setPassedDate(new Date());
		outcontractService.saveOrUpdate(entity);
		outcontractService.redundanceData(entity);

		//调用天鉴系统接口
//		zjkjTianJianSyncService.syncContractSeal(billId);

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        logger.info("弃审后的回调开始-------------------");
        CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
        if (!resp.isSuccess()) {
            logger.info("合同单据【billId-{}】,【billTypeCode-{}】执行撤回操作校验结束，未通过校验，原因：{}", billId, billTypeCode, resp.getMsg());
            return CommonResponse.error(resp.getMsg());
        }
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(null);
		entity.setPassedDate(null);
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	}

}

==> ejc-outcontract-impl-3.0.0-20251031.085358-388-sources.jar: com/ejianc/foundation/outcontract/service/impl/OutcontractBpmServiceImpl.java <==
package com.ejianc.foundation.outcontract.service.impl;

import java.util.Date;

import com.ejianc.foundation.sealApproval.service.IZjkjTianJianSyncService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.foundation.outcontract.bean.OutcontractEntity;
import com.ejianc.foundation.outcontract.bean.OutcontractReviewEntity;
import com.ejianc.foundation.outcontract.service.IOutcontractReviewService;
import com.ejianc.foundation.outcontract.service.IOutcontractService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("outcontract") 
public class OutcontractBpmServiceImpl implements ICommonBusinessService {
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOutcontractService outcontractService;
	@Autowired
	private IZjkjTianJianSyncService zjkjTianJianSyncService;
    
//    @Autowired
//    private IOutcontractReviewService outcontractReviewService;

    @Autowired
    private IBillTypeApi billTypeApi;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		/*OutcontractEntity entity = outcontractService.selectById(billId);
		if("劳务分包".equals(entity.getType())||"专业分包".equals(entity.getType())){
			//没有合同评审不能提交
			OutcontractReviewEntity reviewEntity = outcontractReviewService.selectById(billId);
			if(reviewEntity!=null){
				return CommonResponse.success();
			}else{
				return CommonResponse.error("缺少合同评审信息，不能提交单据！");
			}
		}*/
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(new Date());
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(null);
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/*if(state==0){
			//没有合同评审不能提交
			OutcontractEntity entity = outcontractService.selectById(billId);
			if("劳务分包".equals(entity.getType())||"专业分包".equals(entity.getType())){
				//没有合同评审不能提交
				OutcontractReviewEntity reviewEntity = outcontractReviewService.selectById(billId);
				if(reviewEntity!=null){
					return CommonResponse.success();
				}else{
					return CommonResponse.error("缺少合同评审信息，不能提交单据！");
				}
			}
		}*/
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSignDate(new Date());
		if(state == 1){
			entity.setSubmitDate(new Date());
		}
		entity.setPassedDate(new Date());
		outcontractService.saveOrUpdate(entity);
		outcontractService.redundanceData(entity);

		//调用天鉴系统接口
		logger.info("--------------调用天鉴系统接口start------------------");
		zjkjTianJianSyncService.syncContractSeal(billId);
		logger.info("--------------调用天鉴系统接口end------------------");

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        logger.info("弃审后的回调开始-------------------");
        CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
        if (!resp.isSuccess()) {
            logger.info("合同单据【billId-{}】,【billTypeCode-{}】执行撤回操作校验结束，未通过校验，原因：{}", billId, billTypeCode, resp.getMsg());
            return CommonResponse.error(resp.getMsg());
        }
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		OutcontractEntity entity = outcontractService.selectById(billId);
		entity.setSubmitDate(null);
		entity.setPassedDate(null);
		outcontractService.saveOrUpdate(entity);
		return CommonResponse.success();
	}

}
